@@ -592,7 +592,7 @@ MassSpectrum::tic(const QList<MassSpectrum *> &massSpectra)
 int
 MassSpectrum::combine(const MassSpectrum &other, double mzStart, double mzEnd)
 {
-  qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   // We receive a spectrum that we need to combine into this mass spectrum.
   // However, we need to check each individual DataPoint of the MassSpectrum
@@ -692,24 +692,24 @@ MassSpectrum::subtract(const MassSpectrum &other, double mzStart, double mzEnd)
 
 
 int
-MassSpectrum::combine(const Trace &other, double mzStart, double mzEnd)
+MassSpectrum::combine(const Trace &trace, double mzStart, double mzEnd)
 {
-  qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
-  MassSpectrum oneCopy(other);
+  MassSpectrum mass_spectrum(trace);
 
-  return combine(oneCopy, mzStart, mzEnd);
+  return combine(mass_spectrum, mzStart, mzEnd);
 }
 
 
 int
-MassSpectrum::subtract(const Trace &other, double mzStart, double mzEnd)
+MassSpectrum::subtract(const Trace &trace, double mzStart, double mzEnd)
 {
-  qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
-  MassSpectrum oneCopy(other);
+  MassSpectrum mass_spectrum(trace);
 
-  return subtract(oneCopy, mzStart, mzEnd);
+  return subtract(mass_spectrum, mzStart, mzEnd);
 }
 
 
@@ -975,8 +975,8 @@ MassSpectrum::combine(const QList<MassSpectrum *> &massSpectra,
 
   if(m_removeZeroValDataPoints)
     {
-      qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-               << "Now removing all 0-m/z data points.";
+      //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+               //<< "Now removing all 0-m/z data points.";
 
       removeZeroValDataPoints();
     }
@@ -1272,8 +1272,8 @@ MassSpectrum::subtract(const QList<MassSpectrum *> &massSpectra,
 
   if(m_removeZeroValDataPoints)
     {
-      qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-               << "Now removing all 0-m/z data points.";
+      //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+               //<< "Now removing all 0-m/z data points.";
 
       removeZeroValDataPoints();
     }
@@ -1471,6 +1471,32 @@ MassSpectrum::subtract(const QList<double> &mzList,
   return count;
 }
 
+int
+MassSpectrum::combine(const DataPoint &dataPoint)
+{
+  // We want to combine a DataPoint, so we need to first establish if we are
+  // working in binned mode or not. Because the combination method is not the
+  // same.
+
+  if(m_binningType != msXpS::BinningType::BINNING_TYPE_NONE)
+    return combineBinned(dataPoint);
+  else
+    return Trace::combine(dataPoint);
+}
+
+int
+MassSpectrum::subtract(const DataPoint &dataPoint)
+{
+  // We want to subtract a DataPoint, so we need to first establish if we are
+  // working in binned mode or not. Because the combination method is not the
+  // same.
+
+  if(m_binningType != msXpS::BinningType::BINNING_TYPE_NONE)
+    return subtractBinned(dataPoint);
+  else
+    return Trace::subtract(dataPoint);
+}
+
 //! Combine \p dataPoint into \c this MassSpectrum using bins.
 /*!
 
@@ -1541,7 +1567,8 @@ MassSpectrum::combineBinned(const DataPoint &dataPoint)
     }
 
   // qDebug() << __FILE__ << __LINE__
-  //<< QString::asprintf("Calling binIndex with mz = %.6f and mzShift = %.6f\n",
+  //<< QString::asprintf("Calling binIndex with mz = %.6f and mzShift =
+  //%.6f\n",
   // mz, m_mzShift);
 
   int binIdx = binIndex(mz);
@@ -1549,7 +1576,8 @@ MassSpectrum::combineBinned(const DataPoint &dataPoint)
   if(binIdx == -1)
     qFatal(
       "Fatal error at %s@%d -- %s. "
-      "Failed to find the bin for the m/z value of DataPoint. Program aborted.",
+      "Failed to find the bin for the m/z value of DataPoint. Program "
+      "aborted.",
       __FILE__,
       __LINE__,
       __FUNCTION__);
@@ -1576,12 +1604,15 @@ MassSpectrum::combineBinned(const DataPoint &dataPoint)
 //! Subtract \p dataPoint from \c this MassSpectrum using bins.
 /*!
 
-  This is the reverse operation of the combineBinned(const DataPoint &dataPoint)
+  This is the reverse operation of the combineBinned(const DataPoint
+  &dataPoint)
   operation. Here, the value of \p dataPoint has its sign inverted by
-  multiplying it by -1. Then combineBinned(DataPoint) is called as for a normal
+  multiplying it by -1. Then combineBinned(DataPoint) is called as for a
+  normal
   combine operation.
 
-  \param dataPoint DataPoint instance to be subtracted from \c this MassSpectrum
+  \param dataPoint DataPoint instance to be subtracted from \c this
+  MassSpectrum
 
   \sa combineBinned(const DataPoint &dataPoint)
 
@@ -1912,14 +1943,16 @@ MassSpectrum::setupBinnability(const MassSpectrum &massSpectrum)
    spectra that are to be combined/subtracted).
 
    \c m_binSize: the delta value between two consecutive m/z values in the
-   spectrum (an m/z value is the key of a DataPoint instance). This delta value
+   spectrum (an m/z value is the key of a DataPoint instance). This delta
+   value
    is to be processed using \c m_binSizeType;
 
    \c m_binSizeType : the type of bin to be applied for the computation of the
    effective delta value between two consecutive DataPoint instances in this
    spectrum;
 
-   Depending on both member data above, the number of decimals required for all
+   Depending on both member data above, the number of decimals required for
+   all
    the
    subsequent computations is determined and stored in \c m_decimaPlaces. That
    \c
@@ -1930,7 +1963,7 @@ MassSpectrum::setupBinnability(const MassSpectrum &massSpectrum)
 int
 MassSpectrum::populateSpectrumWithArbitraryBins()
 {
-  qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   if(size() != 0)
     qFatal(
@@ -1962,10 +1995,10 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
       __LINE__,
       __FUNCTION__);
 
-  qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-           << QString::asprintf("bin size: %.6f and decimal places: %d\n",
-                                m_binSize,
-                                m_decimalPlaces);
+  //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+           //<< QString::asprintf("bin size: %.6f and decimal places: %d\n",
+                                //m_binSize,
+                                //m_decimalPlaces);
 
   // Now that we have defined the value of m_decimalPlaces, let's use that
   // value.
@@ -1975,10 +2008,10 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
   double lastMz = ceil((m_maxMz * pow(10, m_decimalPlaces)) - 0.49) /
                   pow(10, m_decimalPlaces);
 
-  qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-           << QString::asprintf("Very first data point: %.6f\n", firstMz)
-           << QString::asprintf("Very last data point to reach: %.6f\n",
-                                lastMz);
+  //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+           //<< QString::asprintf("Very first data point: %.6f\n", firstMz)
+           //<< QString::asprintf("Very last data point to reach: %.6f\n",
+                                //lastMz);
 
   // That is the very first data point in *this spectrum.
 
@@ -1993,7 +2026,7 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
   // lastMz.
 
   // debugCount value used below for debugging purposes.
-  int debugCount = 0;
+  //int debugCount = 0;
 
   while(previousMzBin < lastMz)
     {
@@ -2019,18 +2052,18 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
       currentMz = ceil((currentMz * pow(10, m_decimalPlaces)) - 0.49) /
                   pow(10, m_decimalPlaces);
 
-      if(debugCount == 0)
-        {
-          double mzDiff = currentMz - previousMzBin;
-          qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-                   << QString(
-                        "previousMzBin: %1 - currentMz: %2 - mzDiff: %3 - "
-                        "m_decimalPlaces: %4")
-                        .arg(previousMzBin, 0, 'f', 10)
-                        .arg(currentMz, 0, 'f', 10)
-                        .arg(mzDiff, 0, 'f', 10)
-                        .arg(m_decimalPlaces);
-        }
+			//if(debugCount == 0)
+				//{
+					//double mzDiff = currentMz - previousMzBin;
+					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+									 //<< QString(
+												//"previousMzBin: %1 - currentMz: %2 - mzDiff: %3 - "
+												//"m_decimalPlaces: %4")
+												//.arg(previousMzBin, 0, 'f', 10)
+												//.arg(currentMz, 0, 'f', 10)
+												//.arg(mzDiff, 0, 'f', 10)
+												//.arg(m_decimalPlaces);
+				//}
 
       double roundedMz = ceil((currentMz * pow(10, m_decimalPlaces)) - 0.49) /
                          pow(10, m_decimalPlaces);
@@ -2054,16 +2087,16 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
                  roundedMz);
         }
 
-      if(debugCount == 0)
-        qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-                 << QString("After decimals accounting: roundedMz: %1")
-                      .arg(roundedMz, 0, 'f', 10);
+      //if(debugCount == 0)
+        //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+                 //<< QString("After decimals accounting: roundedMz: %1")
+                      //.arg(roundedMz, 0, 'f', 10);
 
-      if(debugCount == 0)
-        qDebug() << __FILE__ << __LINE__
-                 << QString("Append bin mz: %1 from computation %2\n")
-                      .arg(roundedMz, 0, 'f', 10)
-                      .arg(previousMzBin, 0, 'f', 10);
+      //if(debugCount == 0)
+        //qDebug() << __FILE__ << __LINE__
+                 //<< QString("Append bin mz: %1 from computation %2\n")
+                      //.arg(roundedMz, 0, 'f', 10)
+                      //.arg(previousMzBin, 0, 'f', 10);
 
       append(new DataPoint(roundedMz, 0));
 
@@ -2071,8 +2104,8 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
       previousMzBin = roundedMz;
 
       // Do the debugging only once each 1000 mz values.
-      if(++debugCount == 100)
-        debugCount = 0;
+      //if(++debugCount == 100)
+        //debugCount = 0;
     }
 
 #if 0
@@ -2340,10 +2373,12 @@ MassSpectrum::binIndex(double mz)
       // qDebug() << __FILE__ << __LINE__
       //<< "mz: " << QString("%1").arg(mz, 0, 'f', 10)
       //<< "obligatory bin index (the last bin index):" << returnIndex
-      //<< "with bin's mz:" << QString("%1").arg(at(returnIndex)->m_key, 0, 'f',
+      //<< "with bin's mz:" << QString("%1").arg(at(returnIndex)->m_key, 0,
+      //'f',
       // 10)
       //<< "bin count: size():" << size()
-      //<< "last bin's mz:" << QString("%1").arg(at(size() - 1)->m_key, 0, 'f',
+      //<< "last bin's mz:" << QString("%1").arg(at(size() - 1)->m_key, 0,
+      //'f',
       // 10);
     }
 
@@ -2352,9 +2387,11 @@ MassSpectrum::binIndex(double mz)
   // qDebug() << __FILE__ << __LINE__
   //<< "mz: " << QString("%1").arg(mz, 0, 'f', 10)
   //<< "found bin index:" << returnIndex
-  //<< "with bin's mz:" << QString("%1").arg(at(returnIndex)->m_key, 0, 'f', 10)
+  //<< "with bin's mz:" << QString("%1").arg(at(returnIndex)->m_key, 0, 'f',
+  // 10)
   //<< "bin count: size():" << size()
-  //<< "last bin's mz:" << QString("%1").arg(at(size() - 1)->m_key, 0, 'f', 10);
+  //<< "last bin's mz:" << QString("%1").arg(at(size() - 1)->m_key, 0, 'f',
+  // 10);
 
   return returnIndex;
 }
