@@ -345,6 +345,7 @@ MainWindow::initializeSystemConfig()
   // Handy variables
   QDir testDir;
   QDir finalDir;
+  QString dirString;
   ConfigSetting *configSetting = nullptr;
 
   // Let's store the number of errors, so that we can return true or false.
@@ -362,9 +363,10 @@ MainWindow::initializeSystemConfig()
 
   // From the QSettings config file.
 
-  testDir.setPath(settings.value("dataDir").toString());
+  dirString = settings.value("dataDir").toString();
+  testDir.setPath(dirString);
 
-  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
+  if(!dirString.isEmpty() && testDir.exists() && testDir.isAbsolute())
     {
       // Ah ah, the user already configured a new directory. Fine, let's go
       // with it.
@@ -377,10 +379,9 @@ MainWindow::initializeSystemConfig()
           // Well, if we are on MacOSX, then we need to know where the bundle is
           // located. Then, we'll craft the directory by appending
           // "Contents/Resources/data".
-
-          testDir.setPath(QString("%1/../Resources/massxpert/data")
-                            .arg(QCoreApplication::applicationDirPath()));
-
+          dirString = QString("%1/../Resources/massxpert/data")
+                        .arg(QCoreApplication::applicationDirPath());
+          testDir.setPath(dirString);
           // QMessageBox::information(this,
           //"dir path",
           // QCoreApplication::applicationDirPath(), QMessageBox::Ok);
@@ -392,14 +393,15 @@ MainWindow::initializeSystemConfig()
           // On UNIX, that would be
           // /usr/local/share/msxpertsuite-<modulename>/data
           // that is, /usr/local/share/msxpertsuite-massxpert/data, for example.
-          testDir.setPath(QString("%1").arg(MASSXPERT_DATA_DIR));
-          //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-                   //<< "From the config.h file:" << testDir.absolutePath();
+          dirString = QString("%1").arg(MASSXPERT_DATA_DIR);
+          testDir.setPath(dirString);
+          // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+          //<< "From the config.h file:" << testDir.absolutePath();
         }
 
       // The path must be absolute and must exist.
 
-  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
+      if(!dirString.isEmpty() && testDir.exists() && testDir.isAbsolute())
         {
           // Fantastic, the initial installation directory exists and that is
           // fine.
@@ -419,8 +421,8 @@ MainWindow::initializeSystemConfig()
         }
     }
 
-  //QMessageBox::information(
-    //this, "dataDir path", finalDir.absolutePath(), QMessageBox::Ok);
+  // QMessageBox::information(
+  // this, "dataDir path", finalDir.absolutePath(), QMessageBox::Ok);
 
   // QMessageBox::information(this,
   //"module",
@@ -443,15 +445,16 @@ MainWindow::initializeSystemConfig()
 
   // From the QSettings config file.
 
-  testDir.setPath(settings.value("polChemDefsDir").toString());
+  dirString = settings.value("polChemDefsDir").toString();
+  testDir.setPath(dirString);
 
-  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
+  if(!dirString.isEmpty() && testDir.exists() && testDir.isAbsolute())
     {
       // Ah ah, the user already configured a new directory. Fine, let's go
       // with it.
       finalDir = testDir;
-      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               //<< "From the configSettings file:" << testDir.absolutePath();
+      // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+      //<< "From the configSettings file:" << testDir.absolutePath();
     }
   else
     {
@@ -460,10 +463,9 @@ MainWindow::initializeSystemConfig()
           // Well, if we are on MacOSX, then we need to know where the bundle is
           // located. Then, we'll craft the directory by appending
           // "Contents/Resources/data".
-
-          testDir.setPath(QString("%1/../Resources/massxpert/data/polChemDefs")
-                            .arg(QCoreApplication::applicationDirPath()));
-
+          dirString = QString("%1/../Resources/massxpert/data/polChemDefs")
+                        .arg(QCoreApplication::applicationDirPath());
+          testDir.setPath(dirString);
           // QMessageBox::information(this,
           //"dir path",
           // QCoreApplication::applicationDirPath(), QMessageBox::Ok);
@@ -476,13 +478,14 @@ MainWindow::initializeSystemConfig()
           // /usr/local/share/msxpertsuite/<modulename>/polChemDefs
           // that is, /usr/local/share/msxpertsuite/massxpert/polChemDefs, for
           // example.
-          testDir.setPath(
-            QString("%1/%2").arg(MASSXPERT_DATA_DIR).arg("polChemDefs"));
-          //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-                   //<< "From the config.h file:" << testDir.absolutePath();
+          dirString =
+            QString("%1/%2").arg(MASSXPERT_DATA_DIR).arg("polChemDefs");
+          testDir.setPath(dirString);
+          // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+          //<< "From the config.h file:" << testDir.absolutePath();
         }
 
-  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
+      if(!dirString.isEmpty() && testDir.exists() && testDir.isAbsolute())
         {
           // Fantastic, the initial installation directory exists and that is
           // fine.
@@ -498,13 +501,12 @@ MainWindow::initializeSystemConfig()
           // not found.
           ++errorCount;
           finalDir = testDir;
-
-          qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
         }
     }
 
-  //QMessageBox::information(
-    //this, "dataDir/polChemDefs path", finalDir.absolutePath(), QMessageBox::Ok);
+  // QMessageBox::information(
+  // this, "dataDir/polChemDefs path", finalDir.absolutePath(),
+  // QMessageBox::Ok);
 
   // And now craft the ConfigSetting instance:
 
@@ -524,15 +526,16 @@ MainWindow::initializeSystemConfig()
 
   // From the QSettings config file.
 
-  testDir.setPath(settings.value("polSeqsDir").toString());
+  dirString = settings.value("polSeqsDir").toString();
+  testDir.setPath(dirString);
 
-  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
+  if(!dirString.isEmpty() && testDir.exists() && testDir.isAbsolute())
     {
       // Ah ah, the user already configured a new directory. Fine, let's go
       // with it.
       finalDir = testDir;
-      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               //<< "From the configSettings file:" << testDir.absolutePath();
+      // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+      //<< "From the configSettings file:" << testDir.absolutePath();
     }
   else
     {
@@ -541,10 +544,9 @@ MainWindow::initializeSystemConfig()
           // Well, if we are on MacOSX, then we need to know where the bundle is
           // located. Then, we'll craft the directory by appending
           // "Contents/Resources/data".
-
-          testDir.setPath(QString("%1/../Resources/massxpert/data/polSeqs")
-                            .arg(QCoreApplication::applicationDirPath()));
-
+          dirString = QString("%1/../Resources/massxpert/data/polSeqs")
+                        .arg(QCoreApplication::applicationDirPath());
+          testDir.setPath(dirString);
           // QMessageBox::information(this,
           //"dir path",
           // QCoreApplication::applicationDirPath(), QMessageBox::Ok);
@@ -556,15 +558,15 @@ MainWindow::initializeSystemConfig()
           // That would be /usr/local/share/msxpertsuite/<modulename>/polSeqs
           // that is, /usr/local/share/msxpertsuite/massxpert/polSeqs, for
           // example.
-          testDir.setPath(
-            QString("%1/%2").arg(MASSXPERT_DATA_DIR).arg("polSeqs"));
-          //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-                   //<< "From the config.h file:" << testDir.absolutePath();
+          dirString = QString("%1/%2").arg(MASSXPERT_DATA_DIR).arg("polSeqs");
+          testDir.setPath(dirString);
+          // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+          //<< "From the config.h file:" << testDir.absolutePath();
         }
 
       // The path must be absolute and must exist.
 
-  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
+      if(!dirString.isEmpty() && testDir.exists() && testDir.isAbsolute())
         {
           // Fantastic, the initial installation directory exists and that is
           // fine.
@@ -580,13 +582,11 @@ MainWindow::initializeSystemConfig()
           // not found.
           ++errorCount;
           finalDir = testDir;
-
-          //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
         }
     }
 
-  //QMessageBox::information(
-    //this, "dataDir/polSeqs path", finalDir.absolutePath(), QMessageBox::Ok);
+  // QMessageBox::information(
+  // this, "dataDir/polSeqs path", finalDir.absolutePath(), QMessageBox::Ok);
 
   // And now craft the ConfigSetting instance:
 
@@ -604,9 +604,10 @@ MainWindow::initializeSystemConfig()
 
   // From the QSettings config file.
 
-  testDir.setPath(settings.value("docDir").toString());
+  dirString = settings.value("docDir").toString();
+  testDir.setPath(dirString);
 
-  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
+  if(!dirString.isEmpty() && testDir.exists() && testDir.isAbsolute())
     {
       // Ah ah, the user already configured a new directory. Fine, let's go
       // with it.
@@ -619,14 +620,9 @@ MainWindow::initializeSystemConfig()
           // Well, if we are on MacOSX, then we need to know where the bundle is
           // located. Then, we'll craft the directory by appending
           // "Contents/Resources/doc".
-
-          testDir.setPath(
-            QString("%1/../doc").arg(QCoreApplication::applicationDirPath()));
-
-          testDir.setPath(QString("%1/../Resources/massxpert/doc")
-                            .arg(QCoreApplication::applicationDirPath()));
-
-
+          dirString = QString("%1/../Resources/massxpert/doc")
+                        .arg(QCoreApplication::applicationDirPath());
+          testDir.setPath(dirString);
           // QMessageBox::information(this,
           //"dir path",
           // QCoreApplication::applicationDirPath(), QMessageBox::Ok);
@@ -637,15 +633,16 @@ MainWindow::initializeSystemConfig()
 
           // That would be /usr/local/share/doc/msxpertsuite
           // that is, /usr/local/share/doc/msxpertsuite, for example.
-          testDir.setPath(QString("%1").arg(MASSXPERT_DOC_DIR));
+          dirString = QString("%1").arg(MASSXPERT_DOC_DIR);
+          testDir.setPath(dirString);
         }
 
-      //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-               //<< "massxpert doc dir: " << QString("%1").arg(MASSXPERT_DOC_DIR);
+      // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+      //<< "massxpert doc dir: " << QString("%1").arg(MASSXPERT_DOC_DIR);
 
       // The path must be absolute and must exist.
 
-      if(testDir.exists() && testDir.isAbsolute())
+      if(!dirString.isEmpty() && testDir.exists() && testDir.isAbsolute())
         {
           // Fantastic, the initial installation directory exists and that is
           // fine.
@@ -662,12 +659,12 @@ MainWindow::initializeSystemConfig()
           ++errorCount;
 
           finalDir = testDir;
-          //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
+          // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
         }
     }
 
-  //QMessageBox::information(
-    //this, "doc dir path", finalDir.absolutePath(), QMessageBox::Ok);
+  // QMessageBox::information(
+  // this, "doc dir path", finalDir.absolutePath(), QMessageBox::Ok);
 
   // And now craft the ConfigSetting instance:
 
