@@ -211,6 +211,11 @@ namespace msXpSmassXpert
 						.arg((quintptr) modif)
 						.arg((quintptr) monomer);
 
+				//qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+								 //<< "monomer ptr:" << monomer
+								 //<< "modif ptr:" << modif
+								 //<< text;
+
 					m_ui.modifListWidget->addItem(text);
 				}
 			}
@@ -245,6 +250,10 @@ namespace msXpSmassXpert
 					.arg(iter + 1)
 					.arg((quintptr) monomer);
 
+				//qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+								 //<< "monomer ptr:" << monomer
+								 //<< text;
+
 				m_ui.modifiedMonomerListWidget->addItem(text);
 			}
 
@@ -287,6 +296,11 @@ namespace msXpSmassXpert
 							.arg((quintptr) modif)
 							.arg((quintptr) monomer);
 
+				//qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+								 //<< "monomer ptr:" << monomer
+								 //<< "modif ptr:" << modif
+								 //<< text;
+
 						m_ui.modifListWidget->addItem(text);
 					}
 				}
@@ -346,7 +360,7 @@ namespace msXpSmassXpert
 
 					// The monomer(quintptr) pointer is the third string in the list.
 					ok = false;
-					quintptr pointerCastToInt = stringList.at(2).toInt(&ok);
+					quintptr pointerCastToInt = stringList.at(2).toLongLong(&ok, 10);
 					Monomer *monomer = reinterpret_cast<Monomer *>(pointerCastToInt);
 
 					// Sanity check, are we dealing with the same monomer now
@@ -834,15 +848,23 @@ namespace msXpSmassXpert
 				bool ok = false;
 
 				// The modif(quintptr) pointer is the third string in the list.
-				quintptr pointerCastToInt = stringList.at(3).toInt(&ok);
+				quintptr pointerCastToInt = stringList.at(3).toLongLong(&ok, 10);
 				Modif *modif = reinterpret_cast<Modif *>(pointerCastToInt);
 
+				//qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+					//<< "modif ptr str:" << stringList.at(3)
+					//<< "modif ptr:" << modif;
+
 				// The monomer(quintptr) pointer is the fourth string in the
 				// list.
 				ok = false;
-				pointerCastToInt = stringList.at(4).toInt(&ok);
+				pointerCastToInt = stringList.at(4).toLongLong(&ok, 10);
 				Monomer *monomer = reinterpret_cast<Monomer *>(pointerCastToInt);
 
+				//qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+					//<< "monomer ptr str:" << stringList.at(4)
+					//<< "monomer ptr:" << monomer;
+
 				// qDebug() << __FILE__ << __LINE__
 				// << "Demodifying cast monomer ptr: " << pointerCastToInt
 				// << "with Monomer* ptr: " << monomer;
