@@ -762,15 +762,15 @@ PeakShaperDlg::execute()
     {
       binSize = fwhm / 10;
 
-      qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               << "The bin size as fwhm/10 is:"
-               << QString("%1").arg(binSize, 0, 'f', 6);
+      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+               //<< "The bin size as fwhm/10 is:"
+               //<< QString("%1").arg(binSize, 0, 'f', 6);
     }
   else
     {
-      qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               << "The bin size set by the user is:"
-               << QString("%1").arg(binSize, 0, 'f', 6);
+      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+               //<< "The bin size set by the user is:"
+               //<< QString("%1").arg(binSize, 0, 'f', 6);
     }
 
   // Now configure the combination spectrum.
