@@ -207,7 +207,7 @@ namespace msXpSmineXpert
 					creator = m_ui.creatorLineEdit->text();
 					title = m_ui.titleLineEdit->text();
 
-					mp_plot->savePdf(m_fileName, false, width, height, creator, title);
+					mp_plot->savePdf(m_fileName, width, height, QCP::epNoCosmetic, creator, title);
 					break;
 
 				case GraphicsFormat::GRAPHICS_FORMAT_PNG:
